#include "AdjustImpl.h"
#include "Adj.h"


void AdjustImpl::Init(const char* token, uint32_t secretId, uint32_t info1, uint32_t info2, uint32_t info3, uint32_t info4, bool debug)
{
}

void AdjustImpl::Release()
{
}

void AdjustImpl::logEvent(const char* eventType, std::map<std::string, std::string> eventValue)
{
}

const char* AdjustImpl::getADID()
{
	return "win32";
}